VERSION 5.00
Begin VB.UserControl MandelbrotSet 
   AutoRedraw      =   -1  'True
   ClientHeight    =   2100
   ClientLeft      =   0
   ClientTop       =   0
   ClientWidth     =   2355
   DrawMode        =   6  'Mask Pen Not
   ScaleHeight     =   140
   ScaleMode       =   3  'Pixel
   ScaleWidth      =   157
   ToolboxBitmap   =   "Mandel.ctx":0000
   Begin VB.PictureBox picNew 
      AutoRedraw      =   -1  'True
      BorderStyle     =   0  'None
      Height          =   855
      Left            =   240
      ScaleHeight     =   855
      ScaleWidth      =   975
      TabIndex        =   0
      Top             =   240
      Visible         =   0   'False
      Width           =   975
   End
   Begin VB.Menu ScaleMenu 
      Caption         =   ""
      Begin VB.Menu mnuScale 
         Caption         =   "Scale x&2"
         Index           =   2
      End
      Begin VB.Menu mnuScale 
         Caption         =   "Scale x&4"
         Index           =   4
      End
      Begin VB.Menu mnuScale 
         Caption         =   "Scale x&8"
         Index           =   8
      End
      Begin VB.Menu mnuScaleFull 
         Caption         =   "&Full Scale"
      End
      Begin VB.Menu mnuSep 
         Caption         =   "-"
      End
      Begin VB.Menu mnuIter 
         Caption         =   "&Max Iterations"
      End
   End
End
Attribute VB_Name = "MandelbrotSet"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Description = "CCC Mandelbrot set drawing control"
Option Explicit

' Enumerated values.
Enum mand_BorderStyle
    None_mand_BorderStyle = 0
    Fixed_Single_mand_BorderStyle = 1
End Enum

'Default Property Values:
Const m_def_AllowZoom = False
Const m_def_VisibleXmin = 0#
Const m_def_VisibleXmax = 0#
Const m_def_VisibleYmin = 0#
Const m_def_VisibleYmax = 0#
Const m_def_MaxIterations = 64
Const m_def_Xmin = -2#
Const m_def_Xmax = 1.2
Const m_def_Ymin = -1.2
Const m_def_Ymax = 1.2
'Property Variables:
Dim m_AllowZoom As Boolean
Dim m_VisibleXmin As Single
Dim m_VisibleXmax As Single
Dim m_VisibleYmin As Single
Dim m_VisibleYmax As Single
Dim m_MaxIterations As Integer
Dim m_Xmin As Single
Dim m_Xmax As Single
Dim m_Ymin As Single
Dim m_Ymax As Single
'Event Declarations:
Event Click() 'MappingInfo=UserControl,UserControl,-1,Click
Attribute Click.VB_Description = "Occurs when the user presses and then releases a mouse button over an object."
Event DblClick() 'MappingInfo=UserControl,UserControl,-1,DblClick
Attribute DblClick.VB_Description = "Occurs when the user presses and releases a mouse button and then presses and releases it again over an object."

Dim NumClrs As Integer
Dim ok_clr() As RGBTriplet

Dim skip_draw As Boolean

' Used for zooming.
Dim DrawingBox As Boolean
Dim StartX As Single
Dim StartY As Single
Dim CurX As Single
Dim CurY As Single
' Return a color's red, green, and blue components.
Private Sub SeparateColor(ByVal color As Long, ByRef r As Integer, ByRef g As Integer, ByRef b As Integer)
    r = color And &HFF&
    g = (color And &HFF00&) \ &H100&
    b = (color And &HFF0000) \ &H10000
End Sub

' ************************************************
' Draw the Mandelbrot set.
' ************************************************
Private Sub DrawMandelbrot()
Const MAX_MAG_SQUARED = 4  ' Work until the magnitude squared > 4.

Dim pixels() As RGBTriplet
Dim bits_per_pixel As Integer
Dim wid As Long
Dim hgt As Long

Dim clr As Long
Dim i As Integer
Dim j As Integer
Dim ReaC As Double
Dim ImaC As Double
Dim dReaC As Double
Dim dImaC As Double
Dim ReaZ As Double
Dim ImaZ As Double
Dim ReaZ2 As Double
Dim ImaZ2 As Double

    ' If we do not need to draw, we're done.
    If skip_draw Then
        skip_draw = False
        Exit Sub
    End If
        
    MousePointer = vbHourglass
    DoEvents

    ' Initialize the colors.
    InitColors

    ' Adjust the aspect ratio.
    AdjustAspect

    ' Make room for the image pixels and get the
    ' number of bits per pixel.
    GetBitmapPixels picNew, pixels, bits_per_pixel
    wid = ScaleWidth
    hgt = ScaleHeight

    ' dReaC is the change in the real part
    ' (X value) for C. dImaC is the change in the
    ' imaginary part (Y value).
    dReaC = (m_VisibleXmax - m_VisibleXmin) / (wid - 1)
    dImaC = (m_VisibleYmax - m_VisibleYmin) / (hgt - 1)
    
    ' Calculate the values.
    ReaC = m_VisibleXmin
    For i = 0 To wid - 1
        ImaC = m_VisibleYmin
        For j = 0 To hgt - 1
            ReaZ = 0
            ImaZ = 0
            ReaZ2 = 0
            ImaZ2 = 0
            clr = 1
            Do While clr < m_MaxIterations And _
                    ReaZ2 + ImaZ2 < MAX_MAG_SQUARED
                ' Calculate Z(clr).
                ReaZ2 = ReaZ * ReaZ
                ImaZ2 = ImaZ * ImaZ
                ImaZ = 2 * ImaZ * ReaZ + ImaC
                ReaZ = ReaZ2 - ImaZ2 + ReaC
                clr = clr + 1
            Loop
            pixels(i, j) = ok_clr(clr Mod NumClrs)
            ImaC = ImaC + dImaC
        Next j
        ReaC = ReaC + dReaC
    Next i

    ' Update the bitmap.
    SetBitmapPixels picNew, bits_per_pixel, pixels
    picNew.Picture = picNew.Image
    UserControl.Picture = picNew.Picture
    UserControl.Picture = UserControl.Image

    SetMousePointer
End Sub
' *********************************************
' Fill in an array with the indexes of the
' static colors we want to use.
' *********************************************
Private Sub InitColors()
Static done_before As Boolean
Dim i As Integer
Dim r As Integer
Dim g As Integer
Dim b As Integer

    If done_before Then Exit Sub
    done_before = True

    NumClrs = 16
    ReDim ok_clr(0 To NumClrs - 1)
    For i = 0 To NumClrs - 1
        SeparateColor QBColor(i), r, g, b
        With ok_clr(i)
            .rgbRed = r
            .rgbGreen = g
            .rgbBlue = b
        End With
    Next i
End Sub

Private Sub mnuIter_Click()
Dim txt As String

    txt = InputBox( _
        "Maximum iterations", _
        "Iterations", _
        Format$(m_MaxIterations))
    If IsNumeric(txt) Then MaxIterations = CInt(txt)
End Sub
' *********************************************
' Show the About dialog.
' *********************************************
Public Sub ShowAbout()
Attribute ShowAbout.VB_Description = "Displays the About dialog."
Attribute ShowAbout.VB_UserMemId = -552
Dim frm As New AboutDialog

    frm.Show vbModal
    Set frm = Nothing
End Sub
' ************************************************
' Draw the Mandelbrot set.
' ************************************************
Private Sub EightBitColorDrawMandelbrot()
'Const MAX_MAG_SQUARED = 4  ' Work until the magnitude squared > 4.
'
'Dim bm As BITMAP
'Dim hbm As Long
'Dim status As Long
'Dim bytes() As Byte
'Dim wid As Long
'Dim hgt As Long
'
'Dim clr As Long
'Dim i As Integer
'Dim j As Integer
'Dim ReaC As Double
'Dim ImaC As Double
'Dim dReaC As Double
'Dim dImaC As Double
'Dim ReaZ As Double
'Dim ImaZ As Double
'Dim ReaZ2 As Double
'Dim ImaZ2 As Double
'
'    ' If we do not need to draw, we're done.
'    If skip_draw Then
'        skip_draw = False
'        Exit Sub
'    End If
'
'    MousePointer = vbHourglass
'    DoEvents
'
'    ' Initialize the colors.
'    InitColors
'
'    ' Adjust the aspect ratio.
'    AdjustAspect
'
'    ' Get the image pixels.
'    hbm = Image
'    status = GetObject(hbm, BITMAP_SIZE, bm)
'    wid = bm.bmWidthBytes
'    hgt = bm.bmHeight
'    ReDim bytes(1 To wid, 1 To hgt)
'
'    ' dReaC is the change in the real part
'    ' (X value) for C. dImaC is the change in the
'    ' imaginary part (Y value).
'    dReaC = (m_VisibleXmax - m_VisibleXmin) / (wid - 1)
'    dImaC = (m_VisibleYmax - m_VisibleYmin) / (hgt - 1)
'
'    ' Calculate the values.
'    ReaC = m_VisibleXmin
'    For i = 1 To wid
'        ImaC = m_VisibleYmin
'        For j = 1 To hgt
'            ReaZ = 0
'            ImaZ = 0
'            ReaZ2 = 0
'            ImaZ2 = 0
'            clr = 1
'            Do While clr < m_MaxIterations And _
'                    ReaZ2 + ImaZ2 < MAX_MAG_SQUARED
'                ' Calculate Z(clr).
'                ReaZ2 = ReaZ * ReaZ
'                ImaZ2 = ImaZ * ImaZ
'                ImaZ = 2 * ImaZ * ReaZ + ImaC
'                ReaZ = ReaZ2 - ImaZ2 + ReaC
'                clr = clr + 1
'            Loop
'            bytes(i, j) = ok_clr(clr Mod NumClrs)
'            ImaC = ImaC + dImaC
'        Next j
'        ReaC = ReaC + dReaC
'    Next i
'
'    ' Update the image.
'    status = SetBitmapBits(hbm, wid * hgt, bytes(1, 1))
'    Refresh
'    UserControl.Picture = UserControl.Image
'
'    SetMousePointer
End Sub
' ************************************************
' Adjust the aspect ratio of the selected
' coordinates so they fit the window properly.
' ************************************************
Private Sub AdjustAspect()
Dim want_aspect As Single
Dim canvas_aspect As Single
Dim hgt As Single
Dim wid As Single
Dim mid As Single

    want_aspect = (m_Ymax - m_Ymin) / (m_Xmax - m_Xmin)
    canvas_aspect = ScaleHeight / ScaleWidth
    If want_aspect > canvas_aspect Then
        ' The selected area is too tall and thin.
        ' Make it wider.
        wid = (m_Ymax - m_Ymin) / canvas_aspect
        mid = (m_Xmin + m_Xmax) / 2
        m_VisibleXmin = mid - wid / 2
        m_VisibleXmax = mid + wid / 2
        m_VisibleYmin = m_Ymin
        m_VisibleYmax = m_Ymax
    Else
        ' The selected area is too short and wide.
        ' Make it taller.
        hgt = (m_Xmax - m_Xmin) * canvas_aspect
        mid = (m_Ymin + m_Ymax) / 2
        m_VisibleYmin = mid - hgt / 2
        m_VisibleYmax = mid + hgt / 2
        m_VisibleXmin = m_Xmin
        m_VisibleXmax = m_Xmax
    End If
End Sub
' ************************************************
' Zoom out to full scale.
' ************************************************
Public Sub ScaleFull()
Attribute ScaleFull.VB_Description = "Fades out to full scale."
    m_Xmin = -2
    m_Xmax = 1.2
    m_Ymin = -1.2
    m_Ymax = 1.2
    
    DrawMandelbrot
End Sub
' *********************************************
' Increase the area shown by a factor of fact.
' *********************************************
Private Sub ScaleFactor(fact As Integer)
Dim size As Single
Dim mid As Single

    size = fact * (Xmax - Xmin)
    If size > 3.2 Then
        ScaleFull
        Exit Sub
    End If
    mid = (Xmin + Xmax) / 2
    Xmin = mid - size / 2
    Xmax = mid + size / 2
    
    size = fact * (Ymax - Ymin)
    If size > 2.4 Then
        ScaleFull
        Exit Sub
    End If
    mid = (Ymin + Ymax) / 2
    Ymin = mid - size / 2
    Ymax = mid + size / 2
    
    DrawMandelbrot
End Sub
'WARNING! DO NOT REMOVE OR MODIFY THE FOLLOWING COMMENTED LINES!
'MappingInfo=UserControl,UserControl,-1,BorderStyle
Public Property Get BorderStyle() As mand_BorderStyle
Attribute BorderStyle.VB_Description = "Returns/sets the border style for an object."
    BorderStyle = UserControl.BorderStyle
End Property
Public Property Let BorderStyle(ByVal New_BorderStyle As mand_BorderStyle)
    UserControl.BorderStyle() = New_BorderStyle
    PropertyChanged "BorderStyle"
End Property

' *********************************************
' Force a redraw.
' *********************************************
Public Sub Redraw()
Attribute Redraw.VB_Description = "Makes the control redraw the Mandelbrot set."
    UserControl_Paint
End Sub

' *********************************************
' Use the crosshair pointer if AllowZoom is
' true. Use the default pointer otherwise.
' *********************************************
Private Sub SetMousePointer()
    If m_AllowZoom Then
        MousePointer = vbCrosshair
    Else
        MousePointer = vbDefault
    End If
End Sub

Private Sub mnuScale_Click(Index As Integer)
    ScaleFactor Index
End Sub

Private Sub mnuScaleFull_Click()
    ScaleFull
End Sub

Private Sub UserControl_Click()
    RaiseEvent Click
End Sub

Private Sub UserControl_DblClick()
    RaiseEvent DblClick
End Sub

'WARNING! DO NOT REMOVE OR MODIFY THE FOLLOWING COMMENTED LINES!
'MappingInfo=UserControl,UserControl,-1,Enabled
Public Property Get Enabled() As Boolean
Attribute Enabled.VB_Description = "Returns/sets a value that determines whether an object can respond to user-generated events."
    Enabled = UserControl.Enabled
End Property
Public Property Let Enabled(ByVal New_Enabled As Boolean)
    UserControl.Enabled() = New_Enabled
    PropertyChanged "Enabled"
End Property

'Initialize Properties for User Control
Private Sub UserControl_InitProperties()
    m_Xmin = m_def_Xmin
    m_Xmax = m_def_Xmax
    m_Ymin = m_def_Ymin
    m_Ymax = m_def_Ymax
    m_MaxIterations = m_def_MaxIterations
    m_VisibleXmin = m_def_VisibleXmin
    m_VisibleXmax = m_def_VisibleXmax
    m_VisibleYmin = m_def_VisibleYmin
    m_VisibleYmax = m_def_VisibleYmax
    m_AllowZoom = m_def_AllowZoom

    SetMousePointer

    ' We need to draw since this is a new
    ' control.
    skip_draw = False
End Sub

' ************************************************
' Start a rubberband box to select a zoom area.
' ************************************************
Private Sub UserControl_MouseDown(Button As Integer, Shift As Integer, X As Single, Y As Single)
    If Not m_AllowZoom Then Exit Sub
    
    ' See if it's the right button.
    If Button And vbRightButton Then
        ' If we are in the middle of a zoom,
        ' cancel the zoom.
        If DrawingBox Then
            ' Erase the old box.
            Line (StartX, StartY)-(CurX, CurY), , B
            DrawingBox = False
        Else
            ' Otherwise show the scale menu.
            PopupMenu ScaleMenu, vbPopupMenuRightButton
        End If
        Exit Sub
    End If
    
    ' Otherwise start a zoom.
    DrawingBox = True
    StartX = X
    StartY = Y
    CurX = X
    CurY = Y
    Line (StartX, StartY)-(CurX, CurY), , B
End Sub

' ************************************************
' Continue the zoom area rubberband box.
' ************************************************
Private Sub UserControl_MouseMove(Button As Integer, Shift As Integer, X As Single, Y As Single)
    If Not (DrawingBox And m_AllowZoom) _
        Then Exit Sub
        
    Line (StartX, StartY)-(CurX, CurY), , B
    CurX = X
    CurY = Y
    Line (StartX, StartY)-(CurX, CurY), , B
End Sub

' ************************************************
' Zoom in on the selected area.
' ************************************************
Private Sub UserControl_MouseUp(Button As Integer, Shift As Integer, X As Single, Y As Single)
Dim x1 As Single
Dim x2 As Single
Dim y1 As Single
Dim y2 As Single
Dim factor As Single

    If Not (DrawingBox And m_AllowZoom) _
        Then Exit Sub
    DrawingBox = False
    
    Line (StartX, StartY)-(CurX, CurY), , B
    CurX = X
    CurY = Y
    
    ' Put the coordinates in proper order.
    If CurX < StartX Then
        x1 = CurX
        x2 = StartX
    Else
        x1 = StartX
        x2 = CurX
    End If
    If x1 = x2 Then x2 = x1 + 1
    If CurY < StartY Then
        y1 = CurY
        y2 = StartY
    Else
        y1 = StartY
        y2 = CurY
    End If
    If y1 = y2 Then y2 = y1 + 1

    ' Convert screen coords into drawing coords.
    factor = (Xmax - Xmin) / ScaleWidth
    Xmax = Xmin + x2 * factor
    Xmin = Xmin + x1 * factor

    factor = (Ymax - Ymin) / ScaleHeight
    Ymax = Ymin + y2 * factor
    Ymin = Ymin + y1 * factor

    DrawMandelbrot
End Sub
' *********************************************
' Draw the Mandelbrot set.
' *********************************************
Private Sub UserControl_Paint()
    ' Start from scratch.
    Cls
    
    ' Draw the Mandelbrot set.
    DrawMandelbrot
End Sub
'Load property values from storage
Private Sub UserControl_ReadProperties(PropBag As PropertyBag)
    UserControl.BorderStyle = PropBag.ReadProperty("BorderStyle", 0)
    UserControl.Enabled = PropBag.ReadProperty("Enabled", True)
    m_Xmin = PropBag.ReadProperty("Xmin", m_def_Xmin)
    m_Xmax = PropBag.ReadProperty("Xmax", m_def_Xmax)
    m_Ymin = PropBag.ReadProperty("Ymin", m_def_Ymin)
    m_Ymax = PropBag.ReadProperty("Ymax", m_def_Ymax)
    m_MaxIterations = PropBag.ReadProperty("MaxIterations", m_def_MaxIterations)
    Set Picture = PropBag.ReadProperty("Picture", Nothing)
    m_VisibleXmin = PropBag.ReadProperty("VisibleXmin", m_def_VisibleXmin)
    m_VisibleXmax = PropBag.ReadProperty("VisibleXmax", m_def_VisibleXmax)
    m_VisibleYmin = PropBag.ReadProperty("VisibleYmin", m_def_VisibleYmin)
    m_VisibleYmax = PropBag.ReadProperty("VisibleYmax", m_def_VisibleYmax)
    m_AllowZoom = PropBag.ReadProperty("AllowZoom", m_def_AllowZoom)

    SetMousePointer
    
    ' We do not need to draw if we have
    ' successfully loaded the picture.
    skip_draw = Not (Picture Is Nothing)
End Sub
Private Sub UserControl_Resize()
    picNew.Width = ScaleWidth
    picNew.Height = ScaleHeight
    UserControl_Paint
End Sub

' *********************************************
' Fill in an array with the indexes of the
' static colors we want to use.
' *********************************************
Private Sub EightBitColorInitColors()
'Static done_before As Boolean
'
'    If done_before Then Exit Sub
'    done_before = True
'
'    NumClrs = 16
'    ReDim ok_clr(0 To NumClrs - 1)
'    ok_clr(0) = 0       ' Black
'    ok_clr(1) = 1       ' Dark red
'    ok_clr(2) = 2       ' Dark green
'    ok_clr(3) = 3       ' Dark yellow
'    ok_clr(4) = 4       ' Dark blue
'    ok_clr(5) = 5       ' Dark magenta
'    ok_clr(6) = 6       ' Dark cyan
''   ok_clr( ) = 7       ' Light gray
''   ok_clr( ) = 8       ' Money green
'    ok_clr(7) = 9       ' Sky blue
'    ok_clr(8) = 246     ' Cream
''   ok_clr( ) = 247     ' Light gray
''   ok_clr( ) = 248     ' Medium gray
'    ok_clr(9) = 249     ' Red
'    ok_clr(10) = 250    ' Green
'    ok_clr(11) = 251    ' Yellow
'    ok_clr(12) = 252    ' Blue
'    ok_clr(13) = 253    ' Magenta
'    ok_clr(14) = 254    ' Cyan
'    ok_clr(15) = 255    ' White
End Sub
'Write property values to storage
Private Sub UserControl_WriteProperties(PropBag As PropertyBag)
    Call PropBag.WriteProperty("BorderStyle", UserControl.BorderStyle, 0)
    Call PropBag.WriteProperty("Enabled", UserControl.Enabled, True)
    Call PropBag.WriteProperty("Xmin", m_Xmin, m_def_Xmin)
    Call PropBag.WriteProperty("Xmax", m_Xmax, m_def_Xmax)
    Call PropBag.WriteProperty("Ymin", m_Ymin, m_def_Ymin)
    Call PropBag.WriteProperty("Ymax", m_Ymax, m_def_Ymax)
    Call PropBag.WriteProperty("MaxIterations", m_MaxIterations, m_def_MaxIterations)
    Call PropBag.WriteProperty("Picture", Picture, Nothing)
    Call PropBag.WriteProperty("VisibleXmin", m_VisibleXmin, m_def_VisibleXmin)
    Call PropBag.WriteProperty("VisibleXmax", m_VisibleXmax, m_def_VisibleXmax)
    Call PropBag.WriteProperty("VisibleYmin", m_VisibleYmin, m_def_VisibleYmin)
    Call PropBag.WriteProperty("VisibleYmax", m_VisibleYmax, m_def_VisibleYmax)
    Call PropBag.WriteProperty("AllowZoom", m_AllowZoom, m_def_AllowZoom)
End Sub

Public Property Get Xmin() As Single
Attribute Xmin.VB_Description = "The minimum X coordinate that should be displayed."
    Xmin = m_Xmin
End Property

Public Property Let Xmin(ByVal New_Xmin As Single)
    m_Xmin = New_Xmin
    PropertyChanged "Xmin"
End Property

Public Property Get Xmax() As Single
Attribute Xmax.VB_Description = "The maximum X coordinate that should be displayed."
    Xmax = m_Xmax
End Property

Public Property Let Xmax(ByVal New_Xmax As Single)
    m_Xmax = New_Xmax
    PropertyChanged "Xmax"
End Property

Public Property Get Ymin() As Single
Attribute Ymin.VB_Description = "The minimum Y coordinate that should be displayed."
    Ymin = m_Ymin
End Property

Public Property Let Ymin(ByVal New_Ymin As Single)
    m_Ymin = New_Ymin
    PropertyChanged "Ymin"
End Property
Public Property Get Ymax() As Single
Attribute Ymax.VB_Description = "The maximum Y coordinate that should be displayed."
    Ymax = m_Ymax
End Property

Public Property Let Ymax(ByVal New_Ymax As Single)
    m_Ymax = New_Ymax
    PropertyChanged "Ymax"
End Property

Public Property Get MaxIterations() As Integer
Attribute MaxIterations.VB_Description = "The maximum number of iterations the program performs for each point."
    MaxIterations = m_MaxIterations
End Property

Public Property Let MaxIterations(ByVal New_MaxIterations As Integer)
    If New_MaxIterations < 1 Then New_MaxIterations = 1
    m_MaxIterations = New_MaxIterations
    PropertyChanged "MaxIterations"
End Property

'WARNING! DO NOT REMOVE OR MODIFY THE FOLLOWING COMMENTED LINES!
'MappingInfo=UserControl,UserControl,-1,Picture
Public Property Get Picture() As Picture
Attribute Picture.VB_Description = "Returns/sets a graphic to be displayed in a control."
    Set Picture = UserControl.Picture
End Property
Public Property Set Picture(ByVal New_Picture As Picture)
    Set UserControl.Picture = New_Picture
    PropertyChanged "Picture"
End Property
Public Property Get VisibleXmin() As Single
Attribute VisibleXmin.VB_Description = "The minimum X coordinate actually visible."
    VisibleXmin = m_VisibleXmin
End Property

Public Property Let VisibleXmin(ByVal New_VisibleXmin As Single)
    If Ambient.UserMode = False Then Err.Raise 394
    If Ambient.UserMode Then Err.Raise 393
    m_VisibleXmin = New_VisibleXmin
    PropertyChanged "VisibleXmin"
End Property

Public Property Get VisibleXmax() As Single
Attribute VisibleXmax.VB_Description = "The maximum X coordinate actually visible."
    VisibleXmax = m_VisibleXmax
End Property

Public Property Let VisibleXmax(ByVal New_VisibleXmax As Single)
    If Ambient.UserMode = False Then Err.Raise 394
    If Ambient.UserMode Then Err.Raise 393
    m_VisibleXmax = New_VisibleXmax
    PropertyChanged "VisibleXmax"
End Property

Public Property Get VisibleYmin() As Single
Attribute VisibleYmin.VB_Description = "The minimum Y coordinate actually visible."
    VisibleYmin = m_VisibleYmin
End Property

Public Property Let VisibleYmin(ByVal New_VisibleYmin As Single)
    If Ambient.UserMode = False Then Err.Raise 394
    If Ambient.UserMode Then Err.Raise 393
    m_VisibleYmin = New_VisibleYmin
    PropertyChanged "VisibleYmin"
End Property

Public Property Get VisibleYmax() As Single
Attribute VisibleYmax.VB_Description = "The maximum Y coordinate actually visible."
    VisibleYmax = m_VisibleYmax
End Property

Public Property Let VisibleYmax(ByVal New_VisibleYmax As Single)
    If Ambient.UserMode = False Then Err.Raise 394
    If Ambient.UserMode Then Err.Raise 393
    m_VisibleYmax = New_VisibleYmax
    PropertyChanged "VisibleYmax"
End Property

Public Property Get AllowZoom() As Boolean
Attribute AllowZoom.VB_Description = "Indicates the control should allow the user to zoom in on part of the picture."
    AllowZoom = m_AllowZoom
End Property

Public Property Let AllowZoom(ByVal New_AllowZoom As Boolean)
    m_AllowZoom = New_AllowZoom
    PropertyChanged "AllowZoom"
    SetMousePointer
End Property

